from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from mainnet.api.contract_api import ContractApi
from mainnet.api.mine_api import MineApi
from mainnet.api.wallet_api import WalletApi



# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in active development, breaking changes may be made prior to official release of version 1.  **Important:** This library is in active development   # noqa: E501

    The version of the OpenAPI document: 0.0.2
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from mainnet.configuration import Configuration


class SendRequestItem(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'cashaddr': 'str',
        'value': 'float',
        'unit': 'str'
    }

    attribute_map = {
        'cashaddr': 'cashaddr',
        'value': 'value',
        'unit': 'unit'
    }

    def __init__(self, cashaddr=None, value=None, unit=None, local_vars_configuration=None):  # noqa: E501
        """SendRequestItem - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._cashaddr = None
        self._value = None
        self._unit = None
        self.discriminator = None

        self.cashaddr = cashaddr
        self.value = value
        self.unit = unit

    @property
    def cashaddr(self):
        """Gets the cashaddr of this SendRequestItem.  # noqa: E501


        :return: The cashaddr of this SendRequestItem.  # noqa: E501
        :rtype: str
        """
        return self._cashaddr

    @cashaddr.setter
    def cashaddr(self, cashaddr):
        """Sets the cashaddr of this SendRequestItem.


        :param cashaddr: The cashaddr of this SendRequestItem.  # noqa: E501
        :type cashaddr: str
        """
        if self.local_vars_configuration.client_side_validation and cashaddr is None:  # noqa: E501
            raise ValueError("Invalid value for `cashaddr`, must not be `None`")  # noqa: E501

        self._cashaddr = cashaddr

    @property
    def value(self):
        """Gets the value of this SendRequestItem.  # noqa: E501


        :return: The value of this SendRequestItem.  # noqa: E501
        :rtype: float
        """
        return self._value

    @value.setter
    def value(self, value):
        """Sets the value of this SendRequestItem.


        :param value: The value of this SendRequestItem.  # noqa: E501
        :type value: float
        """
        if self.local_vars_configuration.client_side_validation and value is None:  # noqa: E501
            raise ValueError("Invalid value for `value`, must not be `None`")  # noqa: E501

        self._value = value

    @property
    def unit(self):
        """Gets the unit of this SendRequestItem.  # noqa: E501

        Unit of account.  # noqa: E501

        :return: The unit of this SendRequestItem.  # noqa: E501
        :rtype: str
        """
        return self._unit

    @unit.setter
    def unit(self, unit):
        """Sets the unit of this SendRequestItem.

        Unit of account.  # noqa: E501

        :param unit: The unit of this SendRequestItem.  # noqa: E501
        :type unit: str
        """
        if self.local_vars_configuration.client_side_validation and unit is None:  # noqa: E501
            raise ValueError("Invalid value for `unit`, must not be `None`")  # noqa: E501
        allowed_values = ["bch", "usd", "bit", "bits", "sat", "sats", "satoshi", "satoshis"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and unit not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `unit` ({0}), must be one of {1}"  # noqa: E501
                .format(unit, allowed_values)
            )

        self._unit = unit

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SendRequestItem):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SendRequestItem):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

# flake8: noqa

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in active development, breaking changes may be made prior to official release of version 1.  **Important:** This library is in active development   # noqa: E501

    The version of the OpenAPI document: 0.0.2
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

__version__ = "1.0.0"

# import apis into sdk package
from mainnet.api.contract_api import ContractApi
from mainnet.api.mine_api import MineApi
from mainnet.api.wallet_api import WalletApi

# import ApiClient
from mainnet.api_client import ApiClient
from mainnet.configuration import Configuration
from mainnet.exceptions import OpenApiException
from mainnet.exceptions import ApiTypeError
from mainnet.exceptions import ApiValueError
from mainnet.exceptions import ApiKeyError
from mainnet.exceptions import ApiAttributeError
from mainnet.exceptions import ApiException
# import models into sdk package
from mainnet.models.balance_request import BalanceRequest
from mainnet.models.balance_response import BalanceResponse
from mainnet.models.contract import Contract
from mainnet.models.contract_fn_request import ContractFnRequest
from mainnet.models.contract_fn_response import ContractFnResponse
from mainnet.models.contract_response import ContractResponse
from mainnet.models.deposit_address_response import DepositAddressResponse
from mainnet.models.escrow_request import EscrowRequest
from mainnet.models.max_amount_to_send_request import MaxAmountToSendRequest
from mainnet.models.mine_request import MineRequest
from mainnet.models.scalable_vector_graphic import ScalableVectorGraphic
from mainnet.models.send_max_request import SendMaxRequest
from mainnet.models.send_max_response import SendMaxResponse
from mainnet.models.send_request import SendRequest
from mainnet.models.send_request_item import SendRequestItem
from mainnet.models.send_response import SendResponse
from mainnet.models.serialized_send_request import SerializedSendRequest
from mainnet.models.serialized_wallet import SerializedWallet
from mainnet.models.utxo import Utxo
from mainnet.models.utxo_response import UtxoResponse
from mainnet.models.wallet_request import WalletRequest
from mainnet.models.wallet_response import WalletResponse
from mainnet.models.zero_balance_response import ZeroBalanceResponse




# coding: utf-8

"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in active development, breaking changes may be made prior to official release of version 1.  **Important:** This library is in active development   # noqa: E501

    The version of the OpenAPI document: 0.0.2
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import mainnet
from mainnet.models.contract_fn_request import ContractFnRequest  # noqa: E501
from mainnet.rest import ApiException

class TestContractFnRequest(unittest.TestCase):
    """ContractFnRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test ContractFnRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = mainnet.models.contract_fn_request.ContractFnRequest()  # noqa: E501
        if include_optional :
            return ContractFnRequest(
                contract_id = '0', 
                wallet_id = 'wif:testnet:cNfsPtqN2bMRS7vH5qd8tR8GMvgXyL5BjnGAKgZ8DYEiCrCCQcP6', 
                action = 'spend', 
                get_hex_only = True, 
                utxo_ids = [
                    '1e6442a0d3548bb4f917721184ac1cb163ddf324e2c09f55c46ff0ba521cb89f:0'
                    ]
            )
        else :
            return ContractFnRequest(
                contract_id = '0',
                wallet_id = 'wif:testnet:cNfsPtqN2bMRS7vH5qd8tR8GMvgXyL5BjnGAKgZ8DYEiCrCCQcP6',
                action = 'spend',
        )

    def testContractFnRequest(self):
        """Test ContractFnRequest"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

# flake8: noqa
"""
    Mainnet Cash

    A developer friendly bitcoin cash wallet api  This API is currently in active development, breaking changes may be made prior to official release of version 1.  **Important:** This library is in active development   # noqa: E501

    The version of the OpenAPI document: 0.0.2
    Contact: hello@mainnet.cash
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from mainnet.models.balance_request import BalanceRequest
from mainnet.models.balance_response import BalanceResponse
from mainnet.models.contract import Contract
from mainnet.models.contract_fn_request import ContractFnRequest
from mainnet.models.contract_fn_response import ContractFnResponse
from mainnet.models.contract_response import ContractResponse
from mainnet.models.deposit_address_response import DepositAddressResponse
from mainnet.models.escrow_request import EscrowRequest
from mainnet.models.max_amount_to_send_request import MaxAmountToSendRequest
from mainnet.models.mine_request import MineRequest
from mainnet.models.scalable_vector_graphic import ScalableVectorGraphic
from mainnet.models.send_max_request import SendMaxRequest
from mainnet.models.send_max_response import SendMaxResponse
from mainnet.models.send_request import SendRequest
from mainnet.models.send_request_item import SendRequestItem
from mainnet.models.send_response import SendResponse
from mainnet.models.serialized_send_request import SerializedSendRequest
from mainnet.models.serialized_wallet import SerializedWallet
from mainnet.models.utxo import Utxo
from mainnet.models.utxo_response import UtxoResponse
from mainnet.models.wallet_request import WalletRequest
from mainnet.models.wallet_response import WalletResponse
from mainnet.models.zero_balance_response import ZeroBalanceResponse
